==> device-1.0.0-sources.jar: universum/studios/android/device/connection/ConnectionStateReceiver.java <==
/*
 * =================================================================================================
 *                             Copyright (C) 2016 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License
 * you may obtain at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * You can redistribute, modify or publish any part of the code written within this file but as it
 * is described in the License, the software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.device.connection;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.support.annotation.NonNull;

/**
 * A {@link BroadcastReceiver} used by {@link Connection} implementation to receive actual information
 * about network connection state.
 *
 * @author Martin Albedinsky
 */
public class ConnectionStateReceiver extends BroadcastReceiver {

	/**
	 * Returns the intent filter for {@link ConnectivityManager#CONNECTIVITY_ACTION} action which
	 * should be used when registering this instance of connection receiver.
	 *
	 * @return New instance of {@link IntentFilter}.
	 */
	@NonNull
	public final IntentFilter newIntentFilter() {
		return new IntentFilter(ConnectivityManager.CONNECTIVITY_ACTION);
	}

	/**
	 */
	@Override
	public void onReceive(Context context, Intent intent) {
		ConnectionImpl.getsInstance(context).handleBroadcast(context, intent);
	}
}

==> device-1.0.2-sources.jar: universum/studios/android/device/connection/ConnectionStateReceiver.java <==
/*
 * =================================================================================================
 *                             Copyright (C) 2016 Universum Studios
 * =================================================================================================
 *         Licensed under the Apache License, Version 2.0 or later (further "License" only).
 * -------------------------------------------------------------------------------------------------
 * You may use this file only in compliance with the License. More details and copy of this License
 * you may obtain at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * You can redistribute, modify or publish any part of the code written within this file but as it
 * is described in the License, the software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES or CONDITIONS OF ANY KIND.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * =================================================================================================
 */
package universum.studios.android.device.connection;

import android.Manifest;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.support.annotation.NonNull;
import android.support.annotation.RequiresPermission;

/**
 * A {@link BroadcastReceiver} used by {@link Connection} implementation to receive actual information
 * about network connection state.
 *
 * @author Martin Albedinsky
 */
public class ConnectionStateReceiver extends BroadcastReceiver {

	/**
	 * Returns the intent filter for {@link ConnectivityManager#CONNECTIVITY_ACTION} action which
	 * should be used when registering this instance of connection receiver.
	 *
	 * @return New instance of {@link IntentFilter}.
	 */
	@NonNull
	public final IntentFilter newIntentFilter() {
		return new IntentFilter(ConnectivityManager.CONNECTIVITY_ACTION);
	}

	/**
	 */
	@Override
	@RequiresPermission(Manifest.permission.ACCESS_NETWORK_STATE)
	public void onReceive(@NonNull final Context context, @NonNull final Intent intent) {
		ConnectionImpl.getsInstance(context).handleBroadcast(context, intent);
	}
}
